@@ -53,6 +53,13 @@ SIX_PROBES_MAPPING = {
 }
 
 
+def decode_temp_humid_battery_error(data: bytes) -> tuple[float, float, int, bool]:
+    temp, humi = decode_temp_humid(data[0:3])
+    batt = int(data[-1] & 0x7F)
+    err = bool(data[-1] & 0x80)
+    return temp, humi, batt, err
+
+
 def decode_temp_humid(temp_humid_bytes: bytes) -> tuple[float, float]:
     """Decode potential negative temperatures."""
     base_num = (
@@ -131,6 +138,7 @@ class SensorType(Enum):
     WINDOW = "window"
     VIBRATION = "vibration"
     PRESENCE = "presence"
+    PRESSURE = "pressure"
 
 
 @dataclass
@@ -151,6 +159,7 @@ _MODEL_DB = {
     "H5125": ModelInfo("H5125", SensorType.BUTTON, 6, True),
     "H5126": ModelInfo("H5126", SensorType.BUTTON, 2, True),
     "H5127": ModelInfo("H5127", SensorType.PRESENCE, 0, True),
+    "H5130": ModelInfo("H5130", SensorType.PRESSURE, 1, True),
 }
 
 
@@ -238,16 +247,16 @@ class GoveeBluetoothDeviceData(BluetoothData):
             enc_data = data[6:22]
             enc_crc = data[22:24]
             if not calculate_crc(enc_data) == int.from_bytes(enc_crc, "big"):
-                _LOGGER.debug("CRC check failed for H512x: %s", hex(data))
+                _LOGGER.debug("CRC check failed for H512/3x: %s", hex(data))
                 return
 
             key = time_ms + bytes(12)
             try:
                 decrypted = decrypt_data(key, enc_data)
             except ValueError:
-                _LOGGER.warning("Failed to decrypt H512x: %s", hex(data))
+                _LOGGER.warning("Failed to decrypt H512/3x: %s", hex(data))
                 return
-            _LOGGER.debug("Decrypted H512x: %s - %s", decrypted, decrypted.hex())
+            _LOGGER.debug("Decrypted H512/3x: %s - %s", decrypted, decrypted.hex())
             model_id = decrypted[2]
             # GV5121
             # 01040302640100000000000000000000
@@ -267,6 +276,9 @@ class GoveeBluetoothDeviceData(BluetoothData):
 
             # GV5126
             # 01010b02640100000000000000000000
+
+            # GV5130
+            # 010e0d02640000000000000000000000
             sensor_type = SensorType.BUTTON
             if "GV5121" in local_name or model_id == 3:
                 self.set_device_type("H5121")
@@ -289,6 +301,10 @@ class GoveeBluetoothDeviceData(BluetoothData):
             elif "GV5126" in local_name or model_id == 11:
                 self.set_device_type("H5126")
                 self.set_device_name(f"5126{short_address(address)}")
+            elif "GV5130" in local_name or model_id == 13:
+                self.set_device_type("H5130")
+                self.set_device_name(f"5130{short_address(address)}")
+                sensor_type = SensorType.PRESSURE
             else:
                 return
 
@@ -309,6 +325,14 @@ class GoveeBluetoothDeviceData(BluetoothData):
             elif sensor_type is SensorType.MOTION:
                 if button_number_pressed == 1:
                     self.fire_event("motion", "motion")
+            elif sensor_type is SensorType.PRESSURE:
+                # H5130 is a pressure sensor
+                if button_number_pressed == 16:
+                    self.fire_event("button_0", "press")
+                else:
+                    self.update_predefined_binary_sensor(
+                        BinarySensorDeviceClass.PRESENCE, button_number_pressed == 1
+                    )
             else:
                 self.fire_event(f"button_{button_number_pressed}", "press")
             return
@@ -338,9 +362,7 @@ class GoveeBluetoothDeviceData(BluetoothData):
                 self.set_device_type("H5075")
             else:
                 self.set_device_type("H5072/H5075")
-            temp, humi = decode_temp_humid(data[1:4])
-            batt = int(data[4] & 0x7F)
-            err = bool(data[4] & 0x80)
+            temp, humi, batt, err = decode_temp_humid_battery_error(data[1:5])
             if temp >= MIN_TEMP and temp <= MAX_TEMP and not err:
                 self.update_predefined_sensor(SensorLibrary.TEMPERATURE__CELSIUS, temp)
                 self.update_predefined_sensor(SensorLibrary.HUMIDITY__PERCENTAGE, humi)
@@ -366,6 +388,7 @@ class GoveeBluetoothDeviceData(BluetoothData):
             or (is_5105 := "H5105" in local_name)
             or (is_5174 := "H5174" in local_name)
             or (is_5177 := "H5177" in local_name)
+            or (is_5179 := "GV5179" in local_name)
             or (mgr_id == 0x0001 and msg_length == 8)
         ):
             if is_5108 or msg_length == 8:
@@ -386,11 +409,11 @@ class GoveeBluetoothDeviceData(BluetoothData):
                 self.set_device_type("H5174")
             elif is_5177:
                 self.set_device_type("H5177")
+            elif is_5179:
+                self.set_device_type("GV5179")
             else:
-                self.set_device_type("H5101/H5102/H5104/H5108/H5174/H5177")
-            temp, humi = decode_temp_humid(data[2:5])
-            batt = int(data[5] & 0x7F)
-            err = bool(data[5] & 0x80)
+                self.set_device_type("H5101/H5102/H5104/H5108/H5174/H5177/GV5179")
+            temp, humi, batt, err = decode_temp_humid_battery_error(data[2:6])
             if temp >= MIN_TEMP and temp <= MAX_TEMP and not err:
                 self.update_predefined_sensor(SensorLibrary.TEMPERATURE__CELSIUS, temp)
                 self.update_predefined_sensor(SensorLibrary.HUMIDITY__PERCENTAGE, humi)
@@ -444,9 +467,7 @@ class GoveeBluetoothDeviceData(BluetoothData):
         if msg_length == 9 and (
             "H5178" in local_name or "B5178" in local_name or mgr_id == 0x0001
         ):
-            temp, humi = decode_temp_humid(data[3:6])
-            batt = int(data[6] & 0x7F)
-            err = bool(data[6] & 0x80)
+            temp, humi, batt, err = decode_temp_humid_battery_error(data[3:7])
             sensor_id = data[2]
             device_id = "primary"
             if local_name.startswith("H5178") or local_name.startswith("B5178"):
